cansig package
==============

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   cansig.cluster
   cansig.cnvanalysis
   cansig.integration
   cansig.interface
   cansig.metaanalysis
   cansig.models
   cansig.plotting
   cansig.run

Submodules
----------

cansig.api module
-----------------

.. automodule:: cansig.api
   :members:
   :undoc-members:
   :show-inheritance:

cansig.filesys module
---------------------

.. automodule:: cansig.filesys
   :members:
   :undoc-members:
   :show-inheritance:

cansig.gsea module
------------------

.. automodule:: cansig.gsea
   :members:
   :undoc-members:
   :show-inheritance:

cansig.logger module
--------------------

.. automodule:: cansig.logger
   :members:
   :undoc-members:
   :show-inheritance:

cansig.multirun module
----------------------

.. automodule:: cansig.multirun
   :members:
   :undoc-members:
   :show-inheritance:

cansig.tutorial module
----------------------

.. automodule:: cansig.tutorial
   :members:
   :undoc-members:
   :show-inheritance:

cansig.types module
-------------------

.. automodule:: cansig.types
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: cansig
   :members:
   :undoc-members:
   :show-inheritance:
